@@ -6,11 +6,13 @@ from .entity import (
     BootstrapInfo,
     ClusterConfig,
     ClusterConfigData,
+    Condition,
     DatapipeDataInfo,
     DatapipeServerInfo,
     FileTemplateVariables,
     FilesTemplateVariables,
-    RandomTemplateVariables
+    RandomTemplateVariables,
+    TaskRequest
 )
 from .dto import (
     APIGatewayBlacklistItemDTO,
@@ -18,11 +20,13 @@ from .dto import (
     BootstrapInfoDTO,
     ClusterConfigDTO,
     ClusterConfigDataDTO,
+    ConditionDTO,
     DatapipeDataInfoDTO,
     DatapipeServerInfoDTO,
     FileTemplateVariablesDTO,
     FilesTemplateVariablesDTO,
-    RandomTemplateVariablesDTO
+    RandomTemplateVariablesDTO,
+    TaskRequestDTO
 )
 from .value_obj import (
     UDict,
@@ -32,6 +36,33 @@ from .value_obj import (
 
 
 
+class ConditionAssembler(Assembler):
+    def to_entity(self, dto: ConditionDTO):
+        return Condition(
+            min_cpu_num = None if dto.min_cpu_num is None else UInt(dto.min_cpu_num),
+            max_cpu_num = None if dto.max_cpu_num is None else UInt(dto.max_cpu_num),
+            min_memory_size = None if dto.min_memory_size is None else UInt(dto.min_memory_size),
+            max_memory_size = None if dto.max_memory_size is None else UInt(dto.max_memory_size),
+            min_gpu_num = None if dto.min_gpu_num is None else UInt(dto.min_gpu_num),
+            max_gpu_num = None if dto.max_gpu_num is None else UInt(dto.max_gpu_num),
+            min_gpu_memory_size = None if dto.min_gpu_memory_size is None else UInt(dto.min_gpu_memory_size),
+            max_gpu_memory_size = None if dto.max_gpu_memory_size is None else UInt(dto.max_gpu_memory_size)
+        )
+    def to_dto(self, x:Condition):
+        return ConditionDTO(
+            min_cpu_num = None if x.min_cpu_num is None else x.min_cpu_num.get_value(),
+            max_cpu_num = None if x.max_cpu_num is None else x.max_cpu_num.get_value(),
+            min_memory_size = None if x.min_memory_size is None else x.min_memory_size.get_value(),
+            max_memory_size = None if x.max_memory_size is None else x.max_memory_size.get_value(),
+            min_gpu_num = None if x.min_gpu_num is None else x.min_gpu_num.get_value(),
+            max_gpu_num = None if x.max_gpu_num is None else x.max_gpu_num.get_value(),
+            min_gpu_memory_size = None if x.min_gpu_memory_size is None else x.min_gpu_memory_size.get_value(),
+            max_gpu_memory_size = None if x.max_gpu_memory_size is None else x.max_gpu_memory_size.get_value()
+        )
+condition_assembler=ConditionAssembler()
+
+
+
 class DatapipeServerInfoAssembler(Assembler):
     def to_entity(self, dto: DatapipeServerInfoDTO):
         return DatapipeServerInfo(
@@ -211,3 +242,56 @@ class APIGatewayBlacklistItemAssembler(Assembler):
             limit_reason = x.limit_reason.get_value()
         )
 api_gateway_blacklist_item_assembler=APIGatewayBlacklistItemAssembler()
+
+
+
+class TaskRequestAssembler(Assembler):
+    def to_entity(self, dto: TaskRequestDTO):
+        return TaskRequest(
+            task_name = UStr(dto.task_name),
+            region_id = UStr(dto.region_id),
+            condition = condition_assembler.to_entity(dto.condition),
+            git_url = None if dto.git_url is None else UStr(dto.git_url),
+            git_branch = None if dto.git_branch is None else UStr(dto.git_branch),
+            task_type = None if dto.task_type is None else UStr(dto.task_type),
+            task_template = None if dto.task_template is None else UStr(dto.task_template),
+            task_env = None if dto.task_env is None else UStr(dto.task_env),
+            task_command = None if dto.task_command is None else [UStr(m) for m in dto.task_command],
+            task_arg = None if dto.task_arg is None else [UStr(m) for m in dto.task_arg],
+            task_working_dir = None if dto.task_working_dir is None else UStr(dto.task_working_dir),
+            task_image = None if dto.task_image is None else UStr(dto.task_image),
+            task_start_time = None if dto.task_start_time is None else UStr(dto.task_start_time),
+            priority = UInt(dto.priority),
+            amount = UInt(dto.amount),
+            duration = None if dto.duration is None else UInt(dto.duration),
+            disk_size = None if dto.disk_size is None else UInt(dto.disk_size),
+            end_style = UStr(dto.end_style),
+            restart_policy = UStr(dto.restart_policy),
+            timeout = UInt(dto.timeout),
+            cluster_name = None if dto.cluster_name is None else UStr(dto.cluster_name)
+        )
+    def to_dto(self, x:TaskRequest):
+        return TaskRequestDTO(
+            task_name = x.task_name.get_value(),
+            region_id = x.region_id.get_value(),
+            condition = condition_assembler.to_do(x.condition),
+            git_url = None if x.git_url is None else x.git_url.get_value(),
+            git_branch = None if x.git_branch is None else x.git_branch.get_value(),
+            task_type = None if x.task_type is None else x.task_type.get_value(),
+            task_template = None if x.task_template is None else x.task_template.get_value(),
+            task_env = None if x.task_env is None else x.task_env.get_value(),
+            task_command = None if x.task_command is None else [m.get_value() for m in x.task_command],
+            task_arg = None if x.task_arg is None else [m.get_value() for m in x.task_arg],
+            task_working_dir = None if x.task_working_dir is None else x.task_working_dir.get_value(),
+            task_image = None if x.task_image is None else x.task_image.get_value(),
+            task_start_time = None if x.task_start_time is None else x.task_start_time.get_value(),
+            priority = x.priority.get_value(),
+            amount = x.amount.get_value(),
+            duration = None if x.duration is None else x.duration.get_value(),
+            disk_size = None if x.disk_size is None else x.disk_size.get_value(),
+            end_style = x.end_style.get_value(),
+            restart_policy = x.restart_policy.get_value(),
+            timeout = x.timeout.get_value(),
+            cluster_name = None if x.cluster_name is None else x.cluster_name.get_value()
+        )
+task_request_assembler=TaskRequestAssembler()
