@@ -6,11 +6,13 @@ from .entity import (
     BootstrapInfo,
     ClusterConfig,
     ClusterConfigData,
+    Condition,
     DatapipeDataInfo,
     DatapipeServerInfo,
     FileTemplateVariables,
     FilesTemplateVariables,
-    RandomTemplateVariables
+    RandomTemplateVariables,
+    TaskRequest
 )
 from .do import (
     APIGatewayBlacklistItemDO,
@@ -18,11 +20,13 @@ from .do import (
     BootstrapInfoDO,
     ClusterConfigDO,
     ClusterConfigDataDO,
+    ConditionDO,
     DatapipeDataInfoDO,
     DatapipeServerInfoDO,
     FileTemplateVariablesDO,
     FilesTemplateVariablesDO,
-    RandomTemplateVariablesDO
+    RandomTemplateVariablesDO,
+    TaskRequestDO
 )
 from .value_obj import (
     UDict,
@@ -32,6 +36,33 @@ from .value_obj import (
 
 
 
+class ConditionConverter(Converter):
+    def to_entity(self, do: ConditionDO):
+        return Condition(
+            min_cpu_num = None if do.min_cpu_num is None else UInt(do.min_cpu_num),
+            max_cpu_num = None if do.max_cpu_num is None else UInt(do.max_cpu_num),
+            min_memory_size = None if do.min_memory_size is None else UInt(do.min_memory_size),
+            max_memory_size = None if do.max_memory_size is None else UInt(do.max_memory_size),
+            min_gpu_num = None if do.min_gpu_num is None else UInt(do.min_gpu_num),
+            max_gpu_num = None if do.max_gpu_num is None else UInt(do.max_gpu_num),
+            min_gpu_memory_size = None if do.min_gpu_memory_size is None else UInt(do.min_gpu_memory_size),
+            max_gpu_memory_size = None if do.max_gpu_memory_size is None else UInt(do.max_gpu_memory_size)
+        )
+    def to_do(self, x:Condition):
+        return ConditionDO(
+            min_cpu_num = None if x.min_cpu_num is None else x.min_cpu_num.get_value(),
+            max_cpu_num = None if x.max_cpu_num is None else x.max_cpu_num.get_value(),
+            min_memory_size = None if x.min_memory_size is None else x.min_memory_size.get_value(),
+            max_memory_size = None if x.max_memory_size is None else x.max_memory_size.get_value(),
+            min_gpu_num = None if x.min_gpu_num is None else x.min_gpu_num.get_value(),
+            max_gpu_num = None if x.max_gpu_num is None else x.max_gpu_num.get_value(),
+            min_gpu_memory_size = None if x.min_gpu_memory_size is None else x.min_gpu_memory_size.get_value(),
+            max_gpu_memory_size = None if x.max_gpu_memory_size is None else x.max_gpu_memory_size.get_value()
+        )
+condition_converter=ConditionConverter()
+
+
+
 class DatapipeServerInfoConverter(Converter):
     def to_entity(self, do: DatapipeServerInfoDO):
         return DatapipeServerInfo(
@@ -211,3 +242,56 @@ class APIGatewayBlacklistItemConverter(Converter):
             limit_reason = x.limit_reason.get_value()
         )
 api_gateway_blacklist_item_converter=APIGatewayBlacklistItemConverter()
+
+
+
+class TaskRequestConverter(Converter):
+    def to_entity(self, do: TaskRequestDO):
+        return TaskRequest(
+            task_name = UStr(do.task_name),
+            region_id = UStr(do.region_id),
+            condition = condition_converter.to_entity(do.condition),
+            git_url = None if do.git_url is None else UStr(do.git_url),
+            git_branch = None if do.git_branch is None else UStr(do.git_branch),
+            task_type = None if do.task_type is None else UStr(do.task_type),
+            task_template = None if do.task_template is None else UStr(do.task_template),
+            task_env = None if do.task_env is None else UStr(do.task_env),
+            task_command = None if do.task_command is None else [UStr(m) for m in do.task_command],
+            task_arg = None if do.task_arg is None else [UStr(m) for m in do.task_arg],
+            task_working_dir = None if do.task_working_dir is None else UStr(do.task_working_dir),
+            task_image = None if do.task_image is None else UStr(do.task_image),
+            task_start_time = None if do.task_start_time is None else UStr(do.task_start_time),
+            priority = UInt(do.priority),
+            amount = UInt(do.amount),
+            duration = None if do.duration is None else UInt(do.duration),
+            disk_size = None if do.disk_size is None else UInt(do.disk_size),
+            end_style = UStr(do.end_style),
+            restart_policy = UStr(do.restart_policy),
+            timeout = UInt(do.timeout),
+            cluster_name = None if do.cluster_name is None else UStr(do.cluster_name)
+        )
+    def to_do(self, x:TaskRequest):
+        return TaskRequestDO(
+            task_name = x.task_name.get_value(),
+            region_id = x.region_id.get_value(),
+            condition = condition_converter.to_do(x.condition),
+            git_url = None if x.git_url is None else x.git_url.get_value(),
+            git_branch = None if x.git_branch is None else x.git_branch.get_value(),
+            task_type = None if x.task_type is None else x.task_type.get_value(),
+            task_template = None if x.task_template is None else x.task_template.get_value(),
+            task_env = None if x.task_env is None else x.task_env.get_value(),
+            task_command = None if x.task_command is None else [m.get_value() for m in x.task_command],
+            task_arg = None if x.task_arg is None else [m.get_value() for m in x.task_arg],
+            task_working_dir = None if x.task_working_dir is None else x.task_working_dir.get_value(),
+            task_image = None if x.task_image is None else x.task_image.get_value(),
+            task_start_time = None if x.task_start_time is None else x.task_start_time.get_value(),
+            priority = x.priority.get_value(),
+            amount = x.amount.get_value(),
+            duration = None if x.duration is None else x.duration.get_value(),
+            disk_size = None if x.disk_size is None else x.disk_size.get_value(),
+            end_style = x.end_style.get_value(),
+            restart_policy = x.restart_policy.get_value(),
+            timeout = x.timeout.get_value(),
+            cluster_name = None if x.cluster_name is None else x.cluster_name.get_value()
+        )
+task_request_converter=TaskRequestConverter()
