@@ -9,6 +9,35 @@ from .value_obj import (
 
 
 
+class Condition(Entity):
+    def __init__(
+        self,
+        min_cpu_num: Optional[UInt] = 1,
+        max_cpu_num: Optional[UInt] = 1,
+        min_memory_size: Optional[UInt] = 1,
+        max_memory_size: Optional[UInt] = 1,
+        min_gpu_num: Optional[UInt] = None,
+        max_gpu_num: Optional[UInt] = None,
+        min_gpu_memory_size: Optional[UInt] = None,
+        max_gpu_memory_size: Optional[UInt] = None,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.min_cpu_num = min_cpu_num
+        self.max_cpu_num = max_cpu_num
+        self.min_memory_size = min_memory_size
+        self.max_memory_size = max_memory_size
+        self.min_gpu_num = min_gpu_num
+        self.max_gpu_num = max_gpu_num
+        self.min_gpu_memory_size = min_gpu_memory_size
+        self.max_gpu_memory_size = max_gpu_memory_size
+
+
+
 class DatapipeServerInfo(Entity):
     def __init__(
         self,
@@ -207,4 +236,59 @@ class APIGatewayBlacklistItem(Entity):
         self.ip = ip
         self.creation_time = creation_time
         self.limit_time = limit_time
-        self.limit_reason = limit_reason
\ No newline at end of file
+        self.limit_reason = limit_reason
+
+
+
+class TaskRequest(Entity):
+    def __init__(
+        self,
+        task_name: UStr,
+        region_id: UStr,
+        condition: Condition,
+        git_url: Optional[UStr],
+        git_branch: Optional[UStr],
+        task_type: Optional[UStr] = 'cluster',
+        task_template: Optional[UStr] = None,
+        task_env: Optional[UStr] = None,
+        task_command: Optional[List[UStr]] = ['sleep', '100000'],
+        task_arg: Optional[List[UStr]] = None,
+        task_working_dir: Optional[UStr] = None,
+        task_image: Optional[UStr] = 'alpine:3.12',
+        task_start_time: Optional[UStr] = None,
+        priority: UInt = 3,
+        amount: UInt = 1,
+        duration: Optional[UInt] = None,
+        disk_size: Optional[UInt] = 20,
+        end_style: UStr = 'delete',
+        restart_policy: UStr = 'never',
+        timeout: UInt = 500,
+        cluster_name: Optional[UStr] = None,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.task_name = task_name
+        self.region_id = region_id
+        self.condition = condition
+        self.git_url = git_url
+        self.git_branch = git_branch
+        self.task_type = task_type
+        self.task_template = task_template
+        self.task_env = task_env
+        self.task_command = task_command
+        self.task_arg = task_arg
+        self.task_working_dir = task_working_dir
+        self.task_image = task_image
+        self.task_start_time = task_start_time
+        self.priority = priority
+        self.amount = amount
+        self.duration = duration
+        self.disk_size = disk_size
+        self.end_style = end_style
+        self.restart_policy = restart_policy
+        self.timeout = timeout
+        self.cluster_name = cluster_name
\ No newline at end of file
